@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2008-2022 Vaclav Slavik
+ *  Copyright (C) 2008-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -64,7 +64,6 @@ AttentionBar::AttentionBar(wxWindow *parent)
               wxTAB_TRAVERSAL | wxBORDER_NONE)
 {
 #ifdef __WXOSX__
-    SetWindowVariant(wxWINDOW_VARIANT_SMALL);
     NSView *view = GetHandle();
     view.appearance = [NSAppearance appearanceNamed:NSAppearanceNameAqua];
 #endif
@@ -87,8 +86,8 @@ AttentionBar::AttentionBar(wxWindow *parent)
     btnClose->SetToolTip(_("Hide this notification message"));
 
 #if defined(__WXOSX__) || defined(__WXMSW__)
-    wxFont boldFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    boldFont.SetWeight(wxFONTWEIGHT_BOLD);
+    wxFont boldFont = m_label->GetFont();
+    boldFont.SetWeight(MSW_OR_OTHER(wxFONTWEIGHT_BOLD, wxFONTWEIGHT_SEMIBOLD));
     m_label->SetFont(boldFont);
 #endif
 
@@ -102,7 +101,8 @@ AttentionBar::AttentionBar(wxWindow *parent)
 
     auto labelSizer = new wxBoxSizer(wxVERTICAL);
     labelSizer->Add(m_label, wxSizerFlags().Expand());
-    labelSizer->Add(m_explanation, wxSizerFlags().Expand().Border(wxTOP|wxRIGHT, PX(4)));
+    labelSizer->AddSpacer(PX(1));
+    labelSizer->Add(m_explanation, wxSizerFlags().Expand().Border(wxRIGHT, PX(4)));
     sizer->Add(labelSizer, wxSizerFlags(1).Center().PXDoubleBorder(wxALL));
     sizer->AddSpacer(PX(20));
     auto allButtonsSizer = new wxBoxSizer(wxHORIZONTAL);
