@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -65,6 +65,34 @@ typedef enum
 } Bookmark;
 
 
+/**
+    Optional data attached to CatalogItem.
+
+    Used primarily in connection wiht UsesSymbolicIDsForSource() to provide
+    read source strings.
+ */
+struct SideloadedItemData
+{
+    /// Source string replacement
+    wxString source_string, source_plural_string;
+
+    /// Extracted comments / description (used by 
+    wxArrayString extracted_comments;
+};
+
+/**
+    Optional data attached to Catalog.
+
+    Used primarily in connection wiht UsesSymbolicIDsForSource() to provide
+    read source strings.
+ */
+struct SideloadedCatalogData
+{
+    CatalogPtr reference_file;
+    Language source_language;
+};
+
+
 /** This class holds information about one particular string.
     This includes source string and its occurrences in source code
     (so-called references), translation and translation's status
@@ -99,15 +127,24 @@ class CatalogItem
         /// Gets numeric, 1-based ID
         int GetId() const { return m_id; }
 
+        // Implementation for use in derived classes:
+        virtual wxString GetRawSymbolicId() const { return wxString(); }
+        const wxString& GetRawString() const { return m_string; }
+        const wxString& GetRawPluralString() const { return m_plural; }
+
+        /// Get item's symbolic ID if used by the file
+        wxString GetSymbolicId() const { return m_sideloaded ? GetRawString() : GetRawSymbolicId(); }
+        bool HasSymbolicId() const { return !GetSymbolicId().empty(); }
+
         /// Returns the source string.
-        const wxString& GetString() const { return m_string; }
+        const wxString& GetString() const { return m_sideloaded ? m_sideloaded->source_string : GetRawString(); }
+
+        /// Returns the plural string.
+        const wxString& GetPluralString() const { return m_sideloaded ? m_sideloaded->source_plural_string : GetRawPluralString(); }
 
         /// Does this entry have a msgid_plural?
         bool HasPlural() const { return m_hasPlural; }
 
-        /// Returns the plural string.
-        const wxString& GetPluralString() const { return m_plural; }
-
         /// Does this entry have a msgctxt?
         bool HasContext() const { return m_hasContext; }
 
@@ -138,13 +175,13 @@ class CatalogItem
         const wxString& GetComment() const { return m_comment; }
 
         /// Returns array of all auto comments.
-        const wxArrayString& GetExtractedComments() const { return m_extractedComments; }
+        const wxArrayString& GetExtractedComments() const { return m_sideloaded ? m_sideloaded->extracted_comments : m_extractedComments; }
 
         /// Convenience function: does this entry has a comment?
         bool HasComment() const { return !m_comment.empty(); }
 
         /// Convenience function: does this entry has auto comments?
-        bool HasExtractedComments() const { return !m_extractedComments.empty(); }
+        bool HasExtractedComments() const { return !GetExtractedComments().empty(); }
 
         /// Gets gettext flags. \see SetFlags
         wxString GetFlags() const;
@@ -153,6 +190,9 @@ class CatalogItem
         // empty string otherwise
         wxString GetFormatFlag() const;
 
+        /// Like GetFormatFlags(), but only for internal uses (e.g. fileformat-specific highlighting)
+        virtual std::string GetInternalFormatFlag() const { return std::string(); }
+
         /// Gets value of fuzzy flag.
         bool IsFuzzy() const { return m_isFuzzy; }
         /// Gets value of translated flag.
@@ -235,6 +275,9 @@ class CatalogItem
         void SetIssue(const Issue& issue) { m_issue = std::make_shared<Issue>(issue); }
         void SetIssue(Issue::Severity severity, const wxString& message) { m_issue = std::make_shared<Issue>(severity, message); }
 
+        void AttachSideloadedData(const std::shared_ptr<SideloadedItemData>& d) { m_sideloaded = d; }
+        void ClearSideloadedData() { m_sideloaded.reset(); }
+
     protected:
         // API for subclasses:
         virtual void UpdateInternalRepresentation() = 0;
@@ -300,6 +343,7 @@ class CatalogItem
         Bookmark m_bookmark;
 
         std::shared_ptr<Issue> m_issue;
+        std::shared_ptr<SideloadedItemData> m_sideloaded;
 };
 
 
@@ -319,15 +363,18 @@ class Catalog
         {
             PO,
             POT,
-            XLIFF
+            XLIFF,
+            JSON,
+            JSON_FLUTTER
         };
 
         /// Capabilities of the file type
         enum class Cap
         {
-            Translations,    // Can translations be added (e.g. POTs can't)?
-            LanguageSetting, // Is language code saved in the file?
-            UserComments,    // Can users add comments?
+            Translations,       // Can translations be added (e.g. POTs can't)?
+            LanguageSetting,    // Is language code saved in the file?
+            UserComments,       // Can users add comments?
+            FuzzyTranslations   // Can translations be marked as needing work?
         };
 
         /// Is this file capable of doing these things
@@ -418,10 +465,14 @@ class Catalog
         };
 
         /// Default ctor. Creates empty catalog, you have to call Load.
-        static CatalogPtr Create(Type type = Type::PO);
+        static CatalogPtr Create(Type type);
 
-        /// Ctor that loads the catalog from \a po_file with Load.
-        /// \a flags is CreationFlags combination.
+        /**
+            Ctor that loads the catalog from \a po_file with Load.
+            \a flags is CreationFlags combination.
+
+            This function never returns nullptr. In throws on failure.
+         */
         static CatalogPtr Create(const wxString& filename, int flags = 0);
 
         static bool CanLoadFile(const wxString& extension);
@@ -530,28 +581,19 @@ class Catalog
         /// Returns plural forms count: taken from Plural-Forms header if
         /// present, 0 otherwise (unless there are existing plural forms
         /// translations in the file)
-        unsigned GetPluralFormsCount() const;
-
-        /// Returns true if Plural-Forms header doesn't match plural forms
-        /// usage in catalog items
-        bool HasWrongPluralFormsCount() const;
-
-        /// Does this catalog have any items with plural forms?
-        bool HasPluralItems() const;
-
-        /** Returns status of catalog object: true if ok, false if damaged
-            (i.e. constructor or Load failed).
-         */
-        bool IsOk() const { return m_isOk; }
+        virtual unsigned GetPluralFormsCount() const;
 
         /// Returns catalog's source language (may be invalid, but usually English).
-        Language GetSourceLanguage() const { return m_sourceLanguage; }
+        Language GetSourceLanguage() const { return m_sideloaded ? m_sideloaded->source_language : m_sourceLanguage; }
 
         /// Returns catalog's language (may be invalid).
         virtual Language GetLanguage() const { return m_header.Lang; }
 
         /// Change the catalog's language and update headers accordingly
         virtual void SetLanguage(Language lang);
+
+        /// Whether source text is just symbolic identifier and not actual text
+        bool UsesSymbolicIDsForSource() const { return m_sourceIsSymbolicID && !m_sideloaded; }
             
         /// Returns true if the catalog contains obsolete entries (~.*)
         virtual bool HasDeletedItems() const = 0;
@@ -578,24 +620,47 @@ class Catalog
 
         /// Validates correctness of the translation by running msgfmt
         /// Returns number of errors (i.e. 0 if no errors).
-        virtual ValidationResults Validate(bool wasJustLoaded = false) = 0;
+        virtual ValidationResults Validate(const wxString& fileWithSameContent = wxString());
 
         void AttachCloudSync(std::shared_ptr<CloudSyncDestination> c) { m_cloudSync = c; }
         std::shared_ptr<CloudSyncDestination> GetCloudSync() const { return m_cloudSync; }
 
+        /**
+            Attach source text data from another file to this one.
+
+            This is used to implement showing of actual source text when the in-file source is
+            just symbolic IDs. After calling this function, Get(Plural)String() will no longer
+            return the ID, but will instead return as source text the translation from @a ref
+            (typically you'll want that file to be for English).
+
+            Attaches data from the @a ref file to this one,
+         */
+        void SideloadSourceDataFromReferenceFile(CatalogPtr ref);
+
+        /// Undo the effect of SideloadSourceDataFromReferenceFile()
+        void ClearSideloadedSourceData();
+
+        /// Whether the source text was replaced from another file
+        bool HasSideloadedReferenceFile() const { return m_sideloaded != nullptr; }
+        std::shared_ptr<SideloadedCatalogData> GetSideloadedSourceData() const { return m_sideloaded; }
+
     protected:
         Catalog(Type type);
 
+        /// Perform post-creation processing to e.g. fixup issues, detect missing language etc.
+        virtual void PostCreation();
+
     protected:
         CatalogItemArray m_items;
 
-        bool m_isOk;
         Type m_fileType;
         wxString m_fileName;
         HeaderData m_header;
         Language m_sourceLanguage;
+        bool m_sourceIsSymbolicID = false;
 
         std::shared_ptr<CloudSyncDestination> m_cloudSync;
+        std::shared_ptr<SideloadedCatalogData> m_sideloaded;
 };
 
 #endif // Poedit_catalog_h
