@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2018-2022 Vaclav Slavik
+ *  Copyright (C) 2018-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -25,7 +25,6 @@
 
 #include "catalog_xliff.h"
 
-#include "qa_checks.h"
 #include "configuration.h"
 #include "str_helpers.h"
 #include "utility.h"
@@ -36,7 +35,6 @@
 #include <boost/algorithm/string.hpp>
 
 #include <memory>
-#include <mutex>
 #include <set>
 #include <sstream>
 
@@ -46,10 +44,6 @@ using namespace pugi;
 namespace
 {
 
-// FIXME: This should be per-document mutex in XLIFFCatalog, but that is
-//        currently not accessible from XLIFFCatalogItem, hence a global.
-std::mutex gs_documentMutex;
-
 // Flags required for correct parsing of XML files with no loss of information
 // FIXME: This includes parse_eol, which is undesirable: it converts files to Unix
 //        line endings on save. OTOH without it, we'd have to do the conversion
@@ -211,6 +205,12 @@ bool set_node_text_with_metadata(xml_node node, std::string&& text, const XLIFFS
     }
 }
 
+/// Check if a string contains only digit (e.g. "42")
+inline bool is_numeric_only(const std::string& s)
+{
+    return std::all_of(s.begin(), s.end(), [](char c){ return c >= '0' && c <= '9'; });
+}
+
 
 
 class MetadataExtractor : public pugi::xml_tree_walker
@@ -444,11 +444,17 @@ protected:
 
 
 
-XLIFFReadException::XLIFFReadException(const wxString& filename, const wxString& what)
-    : XLIFFException(wxString::Format(_(L"Error loading file “%s”: %s."), filename, what))
+XLIFFReadException::XLIFFReadException(const wxString& what)
+    : XLIFFException(wxString::Format(_(L"Error while loading XLIFF file: %s"), what))
 {}
 
 
+XLIFFCatalogItem::document_lock::document_lock(XLIFFCatalogItem *parent)
+    : std::lock_guard<std::mutex>(parent->m_owner.m_documentMutex)
+{
+}
+
+
 bool XLIFFCatalog::HasCapability(Catalog::Cap cap) const
 {
     switch (cap)
@@ -456,9 +462,11 @@ bool XLIFFCatalog::HasCapability(Catalog::Cap cap) const
         case Cap::Translations:
             return true;
         case Cap::LanguageSetting:
-            return false; // FIXME: for now
+            return true;
         case Cap::UserComments:
             return false; // FIXME: for now
+        case Cap::FuzzyTranslations:
+            return true;
     }
     return false; // silence VC++ warning
 }
@@ -475,22 +483,22 @@ std::shared_ptr<XLIFFCatalog> XLIFFCatalog::Open(const wxString& filename)
     xml_document doc;
     auto result = doc.load_file(filename.fn_str(), PUGI_PARSE_FLAGS);
     if (!result)
-        throw XLIFFReadException(filename, result.description());
+        throw XLIFFReadException(result.description());
 
     std::shared_ptr<XLIFFCatalog> cat;
 
     auto xliff_root = doc.child("xliff");
     std::string xliff_version = xliff_root.attribute("version").value();
     if (xliff_version == "1.0")
-        cat.reset(new XLIFF1Catalog(filename, std::move(doc), 0));
+        cat.reset(new XLIFF1Catalog(std::move(doc), 0));
     else if (xliff_version == "1.1")
-        cat.reset(new XLIFF1Catalog(filename, std::move(doc), 1));
+        cat.reset(new XLIFF1Catalog(std::move(doc), 1));
     else if (xliff_version == "1.2")
-        cat.reset(new XLIFF1Catalog(filename, std::move(doc), 2));
-    else if (xliff_version == "2.0")
-        cat.reset(new XLIFF2Catalog(filename, std::move(doc)));
+        cat.reset(new XLIFF1Catalog(std::move(doc), 2));
+    else if (xliff_version == "2.0" || xliff_version == "2.1")
+        cat.reset(new XLIFF2Catalog(std::move(doc)));
     else
-        throw XLIFFReadException(filename, wxString::Format(_("unsupported XLIFF version (%s)"), xliff_version));
+        throw XLIFFReadException(wxString::Format(_("unsupported version (%s)"), xliff_version));
 
     cat->Parse(xliff_root);
 
@@ -499,7 +507,7 @@ std::shared_ptr<XLIFFCatalog> XLIFFCatalog::Open(const wxString& filename)
 
 
 bool XLIFFCatalog::Save(const wxString& filename, bool /*save_mo*/,
-                        ValidationResults& /*validation_results*/,
+                        ValidationResults& validation_results,
                         CompilationStatus& /*mo_compilation_status*/)
 {
     if ( wxFileExists(filename) && !wxFile::Access(filename, wxFile::write) )
@@ -519,7 +527,9 @@ bool XLIFFCatalog::Save(const wxString& filename, bool /*save_mo*/,
         return false;
     }
 
-    m_fileName = filename;
+    validation_results = Validate();
+
+    SetFileName(filename);
     return true;
 }
 
@@ -532,25 +542,6 @@ std::string XLIFFCatalog::SaveToBuffer()
 }
 
 
-Catalog::ValidationResults XLIFFCatalog::Validate(bool)
-{
-    // FIXME: move this elsewhere, remove #include "qa_checks.h", configuration.h
-
-    ValidationResults res;
-
-    for (auto& i: m_items)
-        i->ClearIssue();
-
-    res.errors = 0;
-
-#if wxUSE_GUI
-    if (Config::ShowWarnings())
-        res.warnings = QAChecker::GetFor(*this)->Check(*this);
-#endif
-
-    return res;
-}
-
 std::string XLIFFCatalog::GetXPathValue(const char* xpath) const
 {
     auto x = m_doc.child("xliff").select_node(xpath);
@@ -569,7 +560,7 @@ std::string XLIFFCatalog::GetXPathValue(const char* xpath) const
 class XLIFF12CatalogItem : public XLIFFCatalogItem
 {
 public:
-    XLIFF12CatalogItem(int itemId, xml_node node) : XLIFFCatalogItem(itemId, node)
+    XLIFF12CatalogItem(XLIFF1Catalog& owner, int itemId, xml_node node) : XLIFFCatalogItem(owner, itemId, node)
     {
         auto source = node.child("source");
 
@@ -579,13 +570,12 @@ public:
 
         m_string = str::to_wx(extractor.extractedText);
 
-        // TODO: switch to textual IDs in CatalogItem
         std::string id = node.attribute("resname").value();
         if (id.empty())
             id = node.attribute("id").value();
-        // some tools (e.g. Xcode, tool-id="com.apple.dt.xcode") use ID same as text
-        if (!id.empty() && id != m_string)
-            m_extractedComments.push_back("ID: " + str::to_wx(id));
+        // some tools (e.g. Xcode, tool-id="com.apple.dt.xcode") use ID same as text; numeric only is useless to translator too
+        if (!id.empty() && id != m_string && !is_numeric_only(id))
+            m_symbolicId = str::to_wx(id);
 
         auto target = node.child("target");
         if (target)
@@ -621,7 +611,7 @@ public:
         wxASSERT( m_translations.size() == 1 ); // no plurals
 
         // modifications in the pugixml tree can affect other nodes, we must lock the entire document
-        std::lock_guard<std::mutex> lock(gs_documentMutex);
+        document_lock lock(this);
 
         auto target = m_node.child("target");
         if (!target)
@@ -723,9 +713,9 @@ void XLIFF1Catalog::Parse(pugi::xml_node root)
                 continue;
 
             if (m_subversion == 0)
-                m_items.push_back(std::make_shared<XLIFF10CatalogItem>(++id, node));
+                m_items.push_back(std::make_shared<XLIFF10CatalogItem>(*this, ++id, node));
             else
-                m_items.push_back(std::make_shared<XLIFF12CatalogItem>(++id, node));
+                m_items.push_back(std::make_shared<XLIFF12CatalogItem>(*this, ++id, node));
         }
     }
 }
@@ -748,7 +738,7 @@ void XLIFF1Catalog::SetLanguage(Language lang)
 class XLIFF2CatalogItem : public XLIFFCatalogItem
 {
 public:
-    XLIFF2CatalogItem(int itemId, xml_node node) : XLIFFCatalogItem(itemId, node)
+    XLIFF2CatalogItem(XLIFF2Catalog& owner, int itemId, xml_node node) : XLIFFCatalogItem(owner, itemId, node)
     {
         auto source = node.child("source");
 
@@ -758,13 +748,12 @@ public:
 
         m_string = str::to_wx(extractor.extractedText);
 
-        // TODO: switch to textual IDs in CatalogItem
         std::string id = unit().attribute("name").value();
         if (id.empty())
             id = unit().attribute("id").value();
-        // some tools (e.g. Xcode, tool-id="com.apple.dt.xcode") use ID same as text
-        if (!id.empty() && id != m_string)
-            m_extractedComments.push_back("ID: " + str::to_wx(id));
+        // some tools (e.g. Xcode, tool-id="com.apple.dt.xcode") use ID same as text; numeric only is useless to translator too
+        if (!id.empty() && id != m_string && !is_numeric_only(id))
+            m_symbolicId = str::to_wx(id);
 
         auto target = node.child("target");
         if (target)
@@ -797,7 +786,7 @@ public:
         wxASSERT( m_translations.size() == 1 ); // no plurals
 
         // modifications in the pugixml tree can affect other nodes, we must lock the entire document
-        std::lock_guard<std::mutex> lock(gs_documentMutex);
+        document_lock lock(this);
 
         auto target = m_node.child("target");
         if (!target)
@@ -861,7 +850,7 @@ void XLIFF2Catalog::Parse(pugi::xml_node root)
         if (strcmp(node.parent().attribute("translate").value(), "no") == 0)
             continue;
 
-        m_items.push_back(std::make_shared<XLIFF2CatalogItem>(++id, node));
+        m_items.push_back(std::make_shared<XLIFF2CatalogItem>(*this, ++id, node));
     }
 }
 
