@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2018-2022 Vaclav Slavik
+ *  Copyright (C) 2018-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -31,9 +31,13 @@
 
 #include "pugixml.h"
 
+#include <mutex>
 #include <vector>
 
 
+class XLIFFCatalog;
+
+
 class XLIFFException : public Exception
 {
 public:
@@ -43,7 +47,7 @@ public:
 class XLIFFReadException : public XLIFFException
 {
 public:
-    XLIFFReadException(const wxString& filename, const wxString& what);
+    XLIFFReadException(const wxString& what);
 };
 
 
@@ -70,19 +74,28 @@ struct XLIFFStringMetadata
 class XLIFFCatalogItem : public CatalogItem
 {
 public:
-    XLIFFCatalogItem(int id, pugi::xml_node node) : m_node(node)
+    XLIFFCatalogItem(XLIFFCatalog& owner, int id, pugi::xml_node node) : m_owner(owner), m_node(node)
         { m_id = id; }
     XLIFFCatalogItem(const CatalogItem&) = delete;
 
+    wxString GetRawSymbolicId() const override { return m_symbolicId; }
+
 protected:
+    struct document_lock : public std::lock_guard<std::mutex>
+    {
+        document_lock(XLIFFCatalogItem *parent);
+    };
+
+protected:
+    XLIFFCatalog& m_owner;
     pugi::xml_node m_node;
     XLIFFStringMetadata m_metadata;
+    wxString m_symbolicId;
 };
 
 
 class XLIFFCatalog : public Catalog
 {
-
 public:
     ~XLIFFCatalog() {}
 
@@ -99,8 +112,6 @@ public:
 
     std::string SaveToBuffer() override;
 
-    ValidationResults Validate(bool wasJustLoaded) override;
-
     Language GetLanguage() const override { return m_language; }
     void SetLanguage(Language lang) override { m_language = lang; }
 
@@ -112,22 +123,25 @@ public:
     std::string GetXPathValue(const char* xpath) const;
 
 protected:
-    XLIFFCatalog(const wxString& filename, pugi::xml_document&& doc)
-        : Catalog(Type::XLIFF), m_doc(std::move(doc)) { m_fileName = filename; }
+    XLIFFCatalog(pugi::xml_document&& doc)
+        : Catalog(Type::XLIFF), m_doc(std::move(doc)) {}
 
     virtual void Parse(pugi::xml_node root) = 0;
 
 protected:
+    std::mutex m_documentMutex;
     pugi::xml_document m_doc;
     Language m_language;
+
+    friend class XLIFFCatalogItem;
 };
 
 
 class XLIFF1Catalog : public XLIFFCatalog
 {
 public:
-    XLIFF1Catalog(const wxString& filename, pugi::xml_document&& doc, int subversion)
-        : XLIFFCatalog(filename, std::move(doc)),
+    XLIFF1Catalog(pugi::xml_document&& doc, int subversion)
+        : XLIFFCatalog(std::move(doc)),
           m_subversion(subversion)
     {}
 
@@ -143,8 +157,7 @@ protected:
 class XLIFF2Catalog : public XLIFFCatalog
 {
 public:
-    XLIFF2Catalog(const wxString& filename, pugi::xml_document&& doc)
-        : XLIFFCatalog(filename, std::move(doc)) {}
+    XLIFF2Catalog(pugi::xml_document&& doc) : XLIFFCatalog(std::move(doc)) {}
 
     void SetLanguage(Language lang) override;
 
