@@ -30,8 +30,6 @@
 #include "concurrency.h"
 
 #include <wx/string.h>
-#include <wx/stdpaths.h>
-#include <wx/utils.h>
 
 #if wxUSE_GUI
     #include "customcontrols.h"
@@ -59,7 +57,7 @@ class CloudSyncDestination
 public:
     virtual ~CloudSyncDestination() {}
 
-    /// Name of the destination (e.g. Crowding or hostname)
+    /// Name of the destination (e.g. Crowdin or hostname)
     virtual wxString GetName() const = 0;
 
     /// Asynchronously uploads the file. Returned future throws on error.
@@ -89,26 +87,6 @@ public:
 
         return std::make_shared<Dest>(name, std::move(func));
     }
-
-    static wxString GetCacheDir(const wxString& category)
-    {
-        static wxString localBaseDir;
-
-        if (localBaseDir.empty())
-        {
-        #if defined(__WXOSX__)
-            localBaseDir = wxGetHomeDir() + "/Library/Caches/net.poedit.Poedit";
-        #elif defined(__UNIX__)
-            if (!wxGetEnv("XDG_CACHE_HOME", &localBaseDir))
-                localBaseDir = wxGetHomeDir() + "/.cache";
-            localBaseDir += "/poedit";
-        #else
-            localBaseDir = wxStandardPaths::Get().GetUserDataDir() + wxFILE_SEP_PATH + "Cache";
-        #endif
-        }
-
-        return localBaseDir + wxFILE_SEP_PATH + category;
-    }
 };
 
 
@@ -124,7 +102,7 @@ public:
         sizer->SetMinSize(PX(300), -1);
         Activity = new ActivityIndicator(this);
         sizer->AddStretchSpacer();
-        sizer->Add(Activity, wxSizerFlags().Expand().Border(wxALL, PX(25)));
+        sizer->Add(Activity, wxSizerFlags().Expand().Border(wxALL, PX(40)));
         sizer->AddStretchSpacer();
         SetSizerAndFit(sizer);
         CenterOnParent();
@@ -134,7 +112,15 @@ public:
         : CloudSyncProgressWindow(parent)
     {
         // TRANSLATORS: %s is a cloud destination, e.g. "Crowdin" or ftp.wordpress.com etc.
-        Activity->Start(wxString::Format(_(L"Uploading translations to %s…"), dest->GetName()));
+        auto label = wxString::Format(_(L"Uploading translations to %s…"), dest->GetName());
+
+        auto sz = Activity->GetTextExtent(label);
+        Activity->SetSize(wxSize(std::max(PX(300), PX(100) + sz.x), -1));
+
+        Activity->Start(label);
+
+        GetSizer()->SetSizeHints(this);
+        CenterOnParent();
     }
 
     ActivityIndicator *Activity;
