@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2016-2022 Vaclav Slavik
+ *  Copyright (C) 2016-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -50,15 +50,8 @@ inline wxColour sRGB(int r, int g, int b, double a = 1.0)
 
 inline bool IsDarkAppearance(NSAppearance *appearance)
 {
-    if (@available(macOS 10.14, *))
-    {
-        NSAppearanceName appearanceName = [appearance bestMatchFromAppearancesWithNames:@[NSAppearanceNameAqua, NSAppearanceNameDarkAqua]];
-        return [appearanceName isEqualToString:NSAppearanceNameDarkAqua];
-    }
-    else
-    {
-        return false;
-    }
+    NSAppearanceName appearanceName = [appearance bestMatchFromAppearancesWithNames:@[NSAppearanceNameAqua, NSAppearanceNameDarkAqua]];
+    return [appearanceName isEqualToString:NSAppearanceNameDarkAqua];
 }
 
 #else
@@ -264,16 +257,15 @@ ColorScheme::Mode ColorScheme::GetAppMode()
     if (!s_appModeDetermined)
     {
 #ifdef __WXOSX__
-        if (@available(macOS 10.14, *))
-            s_appMode = IsDarkAppearance(NSApp.effectiveAppearance) ? Dark : Light;
-        else
-            s_appMode = Light;
+        s_appMode = IsDarkAppearance(NSApp.effectiveAppearance) ? Dark : Light;
 #else
         auto colBg = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW);
-        if (colBg.Red() < 0x60 && colBg.Green() < 0x60 && colBg.Blue() < 0x60)
-            s_appMode = Dark;
-        else
-            s_appMode = Light;
+    #if wxCHECK_VERSION(3,1,3)
+        auto colFg = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
+        s_appMode = (colFg.GetLuminance() > colBg.GetLuminance()) ? Dark : Light;
+    #else
+        s_appMode = (colBg.Red() < 0x60 && colBg.Green() < 0x60 && colBg.Blue() < 0x60) ? Dark : Light;
+    #endif
 #endif
         s_appModeDetermined = true;
     }
@@ -288,13 +280,14 @@ ColorScheme::Mode ColorScheme::GetWindowMode(wxWindow *win)
     NSView *view = win->GetHandle();
     return IsDarkAppearance(view.effectiveAppearance) ? Dark : Light;
 #else
-    auto colBg = win->GetDefaultAttributes().colBg;
-
     // Use dark scheme for very dark backgrounds:
-    if (colBg.Red() < 0x60 && colBg.Green() < 0x60 && colBg.Blue() < 0x60)
-        return Dark;
-    else
-        return Light;
+    auto colBg = win->GetDefaultAttributes().colBg;
+  #if wxCHECK_VERSION(3,1,3)
+    auto colFg = win->GetDefaultAttributes().colFg;
+    return (colFg.GetLuminance() > colBg.GetLuminance()) ? Dark : Light;
+  #else
+    return (colBg.Red() < 0x60 && colBg.Green() < 0x60 && colBg.Blue() < 0x60) ? Dark : Light;
+  #endif
 #endif
 }
 
