@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2010-2022 Vaclav Slavik
+ *  Copyright (C) 2010-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -70,6 +70,7 @@
 #include <atomic>
 #include <memory>
 #include <mutex>
+#include <type_traits>
 
 #include <wx/app.h>
 #include <wx/weakref.h>
@@ -266,9 +267,9 @@ struct future_unwrapper<dispatch::future<T>>
 };
 
 template<typename F, typename... Args>
-inline auto call_and_unwrap_if_future(F&& f, Args&&... args) -> typename future_unwrapper<typename std::result_of<F(Args...)>::type>::return_type
+inline auto call_and_unwrap_if_future(F&& f, Args&&... args) -> typename future_unwrapper<typename std::invoke_result<F, Args...>::type>::return_type
 {
-    return future_unwrapper<typename std::result_of<F(Args...)>::type>::call_and_unwrap(std::forward<F>(f), std::forward<Args>(args)...);
+    return future_unwrapper<typename std::invoke_result<F, Args...>::type>::call_and_unwrap(std::forward<F>(f), std::forward<Args>(args)...);
 }
 
 } // namespace detail
@@ -295,6 +296,8 @@ void set_current_exception(boost::promise<T>& pr)
 template<typename T>
 void set_current_exception(std::shared_ptr<boost::promise<T>> pr) { set_current_exception(*pr); }
 
+#define RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT() catch ( ... ) { boost::rethrow_exception(dispatch::current_exception()); }
+
 
 template<typename T, typename FutureType>
 class future_base
@@ -359,37 +362,49 @@ public:
     T get() { return this->f_.get(); }
 
     template<typename F>
-    auto then(F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F(typename detail::argument_type<F>::arg0_type)>::type>::type>
+    auto then(F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F, typename detail::argument_type<F>::arg0_type>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         return this->f_.then(detail::background_queue_executor::get(),
                              [f{std::move(continuation)}](boost::future<T> x){
-                                 return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
+                                 try
+                                 {
+                                     return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
+                                 }
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
                              });
     }
 
     template<typename F>
-    auto then_on_main(F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F(typename detail::argument_type<F>::arg0_type)>::type>::type>
+    auto then_on_main(F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F, typename detail::argument_type<F>::arg0_type>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         return this->f_.then(detail::main_thread_executor::get(),
                              [f{std::move(continuation)}](boost::future<T> x) {
-                                 return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
+                                 try
+                                 {
+                                     return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
+                                 }
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
                              });
     }
 
     template<typename Window, typename F>
-    auto then_on_window(Window *self, F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F(T)>::type>::type>
+    auto then_on_window(Window *self, F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F, T>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         wxWeakRef<Window> weak(self);
         return this->f_.then(detail::main_thread_executor::get(),
                              [weak, f{std::move(continuation)}](boost::future<T> x){
-                                 if (weak)
-                                     return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
-                                 else
-                                     BOOST_THROW_EXCEPTION(detail::window_dismissed());
-                             });
+                                 try
+                                 {
+                                     if (weak)
+                                         return detail::call_and_unwrap_if_future(f, cch::unpack_arg(std::move(x)));
+                                     else
+                                         BOOST_THROW_EXCEPTION(detail::window_dismissed());
+                                 }
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
+                            });
     };
 
     template<typename Window>
@@ -432,42 +447,53 @@ public:
     void get() { this->f_.get(); }
 
     template<typename F>
-    auto then(F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F()>::type>::type>
+    auto then(F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         return this->f_.then(detail::background_queue_executor::get(),
                              [f{std::move(continuation)}](boost::future<void> x){
-                                 cch::touch_arg(x);
-                                 return detail::call_and_unwrap_if_future(f);
+                                 try
+                                 {
+                                     cch::touch_arg(x);
+                                     return detail::call_and_unwrap_if_future(f);
+                                 }
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
                              });
     }
 
     template<typename F>
-    auto then_on_main(F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F()>::type>::type>
+    auto then_on_main(F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         return this->f_.then(detail::main_thread_executor::get(),
                              [f{std::move(continuation)}](boost::future<void> x){
-                                 cch::touch_arg(x);
-                                 detail::call_and_unwrap_if_future(f);
+                                 try
+                                 {
+                                     cch::touch_arg(x);
+                                     detail::call_and_unwrap_if_future(f);
+                                 }
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
                              });
 
     }
     template<typename Window, typename F>
-    auto then_on_window(Window *self, F&& continuation) -> future<typename detail::future_unwrapper<typename std::result_of<F()>::type>::type>
+    auto then_on_window(Window *self, F&& continuation) -> future<typename detail::future_unwrapper<typename std::invoke_result<F>::type>::type>
     {
         typedef detail::continuation_calling_helper<typename detail::argument_type<typename std::decay<F>::type>::arg0_type> cch;
         wxWeakRef<Window> weak(self);
         return this->f_.then(detail::main_thread_executor::get(),
                              [weak, f{std::move(continuation)}](boost::future<void> x){
-                                 if (weak)
+                                 try
                                  {
-                                     cch::touch_arg(x);
-                                     detail::call_and_unwrap_if_future(f);
+                                     if (weak)
+                                     {
+                                         cch::touch_arg(x);
+                                         detail::call_and_unwrap_if_future(f);
+                                     }
+                                     else
+                                         BOOST_THROW_EXCEPTION(detail::window_dismissed());
                                  }
-                                 else
-                                     BOOST_THROW_EXCEPTION(detail::window_dismissed());
-
+                                 RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
                              });
     };
 
@@ -496,7 +522,11 @@ auto future_base<T, FutureType>::catch_ex(F&& continuation) -> future<void>
         }
         catch (Ex& ex)
         {
-            f(ex);
+            try
+            {
+                f(ex);
+            }
+            RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
         }
     });
 }
@@ -516,7 +546,11 @@ auto future_base<T, FutureType>::catch_all(F&& continuation) -> future<void>
         }
         catch (...)
         {
-            f(dispatch::current_exception());
+            try
+            {
+                f(dispatch::current_exception());
+            }
+            RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
         }
     });
 }
@@ -572,20 +606,28 @@ void fulfill_promise_from_future(std::shared_ptr<promise<T>> p, future<T>&& f)
 
 /// Enqueue an operation for background processing.
 template<class F>
-inline auto async(F&& f) -> future<typename detail::future_unwrapper<typename std::result_of<F()>::type>::type>
+inline auto async(F&& f) -> future<typename detail::future_unwrapper<typename std::invoke_result<F>::type>::type>
 {
     return {boost::async(detail::background_queue_executor::get(), [f{std::forward<F>(f)}]() {
-        return detail::call_and_unwrap_if_future(f);
+        try
+        {
+            return detail::call_and_unwrap_if_future(f);
+        }
+        RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
     })};
 }
 
 
 /// Run an operation on the main thread.
 template<class F>
-inline auto on_main(F&& f) -> future<typename detail::future_unwrapper<typename std::result_of<F()>::type>::type>
+inline auto on_main(F&& f) -> future<typename detail::future_unwrapper<typename std::invoke_result<F>::type>::type>
 {
     return {boost::async(detail::main_thread_executor::get(), [f{std::forward<F>(f)}]() {
-        return detail::call_and_unwrap_if_future(f);
+        try
+        {
+            return detail::call_and_unwrap_if_future(f);
+        }
+        RETHROW_WITH_BOOST_EXCEPTION_PTR_SUPPORT();
     })};
 }
 
