@@ -81,7 +81,10 @@ public:
     /// Create filename on local filesystem suitable for the remote file
     std::wstring CreateLocalFilename(const ProjectInfo& project, const ProjectFile& file, const Language& lang) const override;
 
-    std::shared_ptr<FileSyncMetadata> ExtractSyncMetadata(Catalog& catalog) override;
+    static std::shared_ptr<FileSyncMetadata> DoExtractSyncMetadata(Catalog& catalog);
+
+    std::shared_ptr<FileSyncMetadata> ExtractSyncMetadata(Catalog& catalog) override
+        { return DoExtractSyncMetadata(catalog); }
 
     /// Asynchronously download specific Crowdin file into @a output_file.
     dispatch::future<void> DownloadFile(const std::wstring& output_file, const ProjectInfo& project, const ProjectFile& file, const Language& lang) override;
