@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2015-2022 Vaclav Slavik
+ *  Copyright (C) 2015-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -30,6 +30,7 @@
 
 #ifdef HAVE_HTTP_CLIENT
 
+#include "cloud_accounts_ui.h"
 #include "cloud_sync.h"
 #include "customcontrols.h"
 
@@ -42,18 +43,28 @@ class WXDLLIMPEXP_FWD_CORE wxButton;
 /**
     Panel used to sign in into Crowdin.
  */
-class CrowdinLoginPanel : public wxPanel
+class CrowdinLoginPanel : public AccountDetailPanel
 {
 public:
+    /// Constructor flags
     enum Flags
     {
-        DialogButtons = 1
+        /// Add wxID_CANCEL dialog button to the panel
+        AddCancelButton = 1
     };
 
     CrowdinLoginPanel(wxWindow *parent, int flags = 0);
 
-    /// Call this when the window is first shown
-    void EnsureInitialized();
+    wxString GetServiceName() const override { return "Crowdin"; }
+    wxString GetServiceLogo() const override { return "CrowdinLogo"; }
+    wxString GetServiceDescription() const override;
+    wxString GetServiceLearnMoreURL() const override;
+
+    void InitializeAfterShown() override;
+    bool IsSignedIn() const override;
+    wxString GetLoginName() const override { return m_userLogin; }
+
+    void SignIn() override;
 
 protected:
     enum class State
@@ -71,7 +82,7 @@ protected:
 
     void OnSignIn(wxCommandEvent&);
     void OnSignOut(wxCommandEvent&);
-    virtual void OnUserSignedIn();
+    void OnUserSignedIn();
 
     State m_state;
     ActivityIndicator *m_activity;
@@ -82,37 +93,9 @@ protected:
 };
 
 
-class CrowdinSyncDestination : public CloudSyncDestination
-{
-public:
-    wxString GetName() const override { return "Crowdin"; }
-    bool AuthIfNeeded(wxWindow* parent) override;
-    dispatch::future<void> Upload(CatalogPtr file) override;
-};
-
-
-/// Link to learn about Crowdin
-class LearnAboutCrowdinLink : public LearnMoreLink
-{
-public:
-    LearnAboutCrowdinLink(wxWindow *parent, const wxString& text = "");
-};
-
-
 /// Can given file by synced to Crowdin, i.e. does it come from Crowdin and does it have required metadata?
 bool CanSyncWithCrowdin(CatalogPtr cat);
 
-/// Was the file opened directly from Crowdin and should be synced when the user saves it?
-bool ShouldSyncToCrowdinAutomatically(CatalogPtr cat);
-
-/**
-    Let the user choose a Crowdin file, download it and open in Poedit.
-    
-    @param parent    PoeditFrame the UI should be shown under.
-    @param onDone    Called with the dialog return value (wxID_OK/CANCEL) and name of loaded PO file.
- */
-void CrowdinOpenFile(wxWindow *parent, std::function<void(int, wxString)> onDone);
-
 /**
     Synces the catalog with Crowdin, uploading and downloading translations.
 
