@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2016-2022 Vaclav Slavik
+ *  Copyright (C) 2016-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -73,8 +73,8 @@
     {
         self.title = label;
         self.heading = heading;
-        self.buttonType = NSMomentaryPushInButton;
-        self.bezelStyle = NSTexturedRoundedBezelStyle;
+        self.buttonType = NSButtonTypeMomentaryPushIn;
+        self.bezelStyle = NSBezelStyleTexturedRounded;
         self.showsBorderOnlyWhileMouseInside = YES;
         self.mouseHover = NO;
     }
@@ -97,13 +97,9 @@
     NSColor *bg = self.window.backgroundColor;
     if (self.mouseHover)
     {
-        if (@available(macOS 10.14, *)) {
-            NSColor *highlight = [bg colorWithSystemEffect:NSColorSystemEffectRollover];
-            // use only lighter version of the highlight by blending with the background
-            bg = [bg blendedColorWithFraction:0.2 ofColor:highlight];
-        } else {
-            bg = [NSColor colorWithWhite:0.9 alpha:1.0];
-        }
+        NSColor *highlight = [bg colorWithSystemEffect:NSColorSystemEffectRollover];
+        // use only lighter version of the highlight by blending with the background
+        bg = [bg blendedColorWithFraction:0.2 ofColor:highlight];
     }
     [StyleKit drawActionButtonWithFrame:self.bounds
                             buttonColor:bg
@@ -172,8 +168,8 @@ ActionButton::ActionButton(wxWindow *parent, wxWindowID winid, const wxString& s
     if (self)
     {
         self.title = label;
-        self.bezelStyle = NSSmallSquareBezelStyle;
-        self.buttonType = NSOnOffButton;
+        self.bezelStyle = NSBezelStyleSmallSquare;
+        self.buttonType = NSButtonTypeOnOff;
         self.font = [NSFont boldSystemFontOfSize:[NSFont smallSystemFontSize]];
         self.animationPosition = 0.0;
         self.onColor = [NSColor colorWithCalibratedRed:0.302 green:0.847 blue:0.396 alpha:1.0];
@@ -221,13 +217,13 @@ ActionButton::ActionButton(wxWindow *parent, wxWindowID winid, const wxString& s
     if (state == self.state)
         return;
     [super setState:state];
-    self.animationPosition = (state == NSOnState) ? 1.0 : 0.0;
+    self.animationPosition = (state == NSControlStateValueOn) ? 1.0 : 0.0;
 }
 
 - (void)controlAction:(id)sender
 {
     #pragma unused(sender)
-    double target = (self.state == NSOnState) ? 1.0 : 0.0;
+    double target = (self.state == NSControlStateValueOn) ? 1.0 : 0.0;
 
     [NSAnimationContext runAnimationGroup:^(NSAnimationContext *context)
     {
@@ -261,12 +257,12 @@ public:
 
     void SetValue(bool value)
     {
-        m_view.state = value ? NSOnState : NSOffState;
+        m_view.state = value ? NSControlStateValueOn : NSControlStateValueOff;
     }
 
     bool GetValue() const
     {
-        return m_view.state == NSOnState;
+        return m_view.state == NSControlStateValueOn;
     }
 
 private:
@@ -411,9 +407,24 @@ SwitchButton::SwitchButton(wxWindow *parent, wxWindowID winid, const wxString& l
     SetBackgroundColour(parent->GetBackgroundColour());
     MakeOwnerDrawn();
     Bind(wxEVT_LEFT_DOWN, &SwitchButton::OnMouseClick, this);
-#endif
+#if wxUSE_ACCESSIBILITY
+    Bind(wxEVT_TOGGLEBUTTON, [=](wxCommandEvent& e) {
+        wxAccessible::NotifyEvent(wxACC_EVENT_OBJECT_STATECHANGE, this, wxOBJID_CLIENT, wxACC_SELF);
+        e.Skip();
+    });
+#endif // wxUSE_ACCESSIBILITY
+#endif // __WXMSW__
 }
 
+#ifdef __WXMSW__
+#if wxUSE_ACCESSIBILITY
+wxAccessible* SwitchButton::CreateAccessible() 
+{
+    return new accessible(this);
+}
+#endif // wxUSE_ACCESSIBILITY
+#endif // __WXMSW__
+
 void SwitchButton::SetColors(const wxColour& on, const wxColour& offLabel)
 {
     (void)on;
@@ -550,6 +561,49 @@ bool SwitchButton::MSWOnDraw(WXDRAWITEMSTRUCT *wxdis)
     return true;
 }
 
+#if wxUSE_ACCESSIBILITY
+wxAccStatus SwitchButton::accessible::GetRole(int childId, wxAccRole* role)
+{
+    if (childId != wxACC_SELF)
+    {
+        return wxAccessible::GetRole(childId, role);
+    }
+    *role = wxROLE_SYSTEM_CHECKBUTTON;
+    return wxACC_OK;
+}
+
+wxAccStatus SwitchButton::accessible::GetState(int childId, long* state)
+{
+    if (childId != wxACC_SELF)
+    {
+        return wxAccessible::GetState(childId, state);
+    }
+    auto window = dynamic_cast<SwitchButton*>(this->GetWindow());
+    if (window->IsFocusable())
+    {
+        *state |= wxACC_STATE_SYSTEM_FOCUSABLE;
+    }
+    if (!window->IsShown())
+    {
+        *state |= wxACC_STATE_SYSTEM_INVISIBLE;
+    }
+    if (window->GetValue())
+    {
+        *state |= wxACC_STATE_SYSTEM_CHECKED;
+    }
+    if (!window->IsEnabled())
+    {
+        *state |= wxACC_STATE_SYSTEM_UNAVAILABLE;
+    }
+    if (window->HasFocus())
+    {
+        *state |= wxACC_STATE_SYSTEM_FOCUSED;
+    }
+    return wxACC_OK;
+}
+
+#endif // wxUSE_ACCESSIBILITY
+
 #endif // __WXMSW__
 
 #endif // !__WXOSX__
@@ -574,8 +628,8 @@ bool SwitchButton::MSWOnDraw(WXDRAWITEMSTRUCT *wxdis)
     if (self)
     {
         self.title = label;
-        self.bezelStyle = NSRoundRectBezelStyle;
-        self.buttonType = NSMomentaryPushInButton;
+        self.bezelStyle = NSBezelStyleRoundRect;
+        self.buttonType = NSButtonTypeMomentaryPushIn;
         self.font = [NSFont systemFontOfSize:[NSFont smallSystemFontSize]];
     }
     return self;
