@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2016-2022 Vaclav Slavik
+ *  Copyright (C) 2016-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -114,12 +114,24 @@ public:
     void SetColors(const wxColour& on, const wxColour& offLabel);
 
 #ifdef __WXMSW__
+#if wxUSE_ACCESSIBILITY
+    wxAccessible* CreateAccessible() override;
+#endif // wxUSE_ACCESSIBILITY
     bool ShouldInheritColours() const override { return true; }
     void OnMouseClick(wxMouseEvent& e);
     bool MSWOnDraw(WXDRAWITEMSTRUCT *wxdis) override;
     wxSize DoGetBestSize() const override;
 
 private:
+#if wxUSE_ACCESSIBILITY
+    class accessible : public wxAccessible
+    {
+    public:
+        accessible(SwitchButton* win) : wxAccessible(wxDynamicCast(win, wxWindow)) {}
+        wxAccStatus GetRole(int childId, wxAccRole* role) override;
+        wxAccStatus GetState(int childId, long* state) override;
+    };
+#endif // wxUSE_ACCESSIBILITY
     wxColour m_clrOn, m_clrOffLabel;
 #endif // __WXMSW__
 };
