@@ -340,9 +340,16 @@ public:
 
         button->Bind(wxEVT_TOGGLEBUTTON, [=](wxCommandEvent& e)
         {
-            // SetSelection() generates events:
             if (e.IsChecked())
+            {
+                // SetSelection() generates events:
                 m_book->SetSelection(n);
+            }
+            else
+            {
+                // don't un-toggle already toggled button / selection
+                button->SetValue(true);
+            }
         });
     }
 
@@ -502,6 +509,9 @@ SegmentedNotebook::SegmentedNotebook(wxWindow *parent, SegmentStyle style)
         case SegmentStyle::LargeFullWidth:
             size *= 1.2;
             break;
+        case SegmentStyle::SidebarPanels:
+            // do nothing
+            break;
     }
 
     font.SetFractionalPointSize(size);
