@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2022 Vaclav Slavik
+ *  Copyright (C) 2014-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -31,8 +31,10 @@
 #include "language.h"
 
 #include <wx/bmpbuttn.h>
+#include <wx/dataview.h>
 #include <wx/statbmp.h>
 #include <wx/stattext.h>
+#include <wx/statline.h>
 #include <wx/hyperlink.h>
 #include <wx/xrc/xmlres.h>
 
@@ -257,4 +259,40 @@ private:
 };
 
 
+/// wxDataViewListCtrl with icon and two-line content
+class IconAndSubtitleListCtrl : public wxDataViewListCtrl
+{
+public:
+    IconAndSubtitleListCtrl(wxWindow *parent, const wxString& columnTitle, long style = wxBORDER_NONE);
+
+    void AppendFormattedItem(const wxBitmap& icon, const wxString& title, const wxString& description);
+    void UpdateFormattedItem(unsigned row, const wxString& title, const wxString& description);
+
+protected:
+    int GetDefaultRowHeight() const;
+    wxString FormatItemText(const wxString& title, const wxString& description);
+
+private:
+#ifndef __WXGTK__
+    void OnColorChange();
+    wxString GetSecondaryFormatting();
+    wxString m_secondaryFormatting[2];
+#endif
+
+    class MultilineTextRenderer;
+};
+
+
+/// Fix for a wxStaticLine bug on macOS Ventura
+#if defined(__WXOSX__) && !wxCHECK_VERSION(3,2,3)
+class StaticLine : public wxStaticLine
+{
+public:
+    StaticLine(wxWindow *parent, wxWindowID id);
+};
+#else
+typedef wxStaticLine StaticLine;
+#endif
+
+
 #endif // Poedit_customcontrols_h
