@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -83,8 +83,10 @@ class PoeditFrame : public PoeditFrameBase
         /// if there's unsaved document.
         void OpenFile(const wxString& filename, int lineno = 0);
 
+        static CatalogPtr PreOpenFileWithErrorsUI(const wxString& filename, wxWindow *parent);
+
         // Opens given file in this frame, without asking user
-        void DoOpenFile(const wxString& filename, int lineno = 0);
+        void DoOpenFile(CatalogPtr cat, int lineno = 0);
 
         // Re-read the file from disk if it changed externally
         void ReloadFileIfChanged();
@@ -104,8 +106,6 @@ class PoeditFrame : public PoeditFrameBase
 
         ~PoeditFrame();
 
-        /// Reads catalog, refreshes controls, takes ownership of catalog.
-        void ReadCatalog(const wxString& catalog);
         /// Reads catalog, refreshes controls, takes ownership of catalog.
         void ReadCatalog(const CatalogPtr& cat);
         /// Writes catalog.
@@ -116,6 +116,8 @@ class PoeditFrame : public PoeditFrameBase
 
         void FixDuplicatesIfPresent();
         void WarnAboutLanguageIssues();
+        void SideloadSourceTextFromFile(const wxFileName& fn);
+        void OfferSideloadingSourceText();
 
         /// Did the user modify the catalog?
         bool IsModified() const { return m_modified; }
@@ -154,9 +156,6 @@ class PoeditFrame : public PoeditFrameBase
 
         void NewFromScratch();
         void NewFromPOT(POCatalogPtr pot, Language language = Language());
-#ifdef HAVE_HTTP_CLIENT
-        void NewFromCrowdin(const wxString& filename);
-#endif
 
     protected:
         // Don't show help in status bar, it's not common to do these days:
@@ -173,7 +172,7 @@ class PoeditFrame : public PoeditFrameBase
         enum class Content
         {
             Invalid, // no content whatsoever
-            PO,
+            Translation,
             POT,
             Empty_PO
         };
@@ -259,7 +258,8 @@ private:
         template<typename F>
         void GetSaveAsFilenameThenDo(const CatalogPtr& cat, F then);
         void DoSaveAs(const wxString& filename);
-        void OnProperties(wxCommandEvent& event);
+        void OnEditProperties(wxCommandEvent& event);
+        void OnUpdateEditProperties(wxUpdateUIEvent& event);
 
         void OnUpdateFromSources(wxCommandEvent& event);
         void OnUpdateFromSourcesUpdate(wxUpdateUIEvent& event);
@@ -314,6 +314,7 @@ private:
         void OnHasCatalogUpdate(wxUpdateUIEvent& event);
         void OnIsEditableUpdate(wxUpdateUIEvent& event);
         void OnEditCommentUpdate(wxUpdateUIEvent& event);
+        void OnFuzzyFlagUpdate(wxUpdateUIEvent& event);
 
 #if defined(__WXMSW__) || defined(__WXGTK__)
         void OnTextEditingCommand(wxCommandEvent& event);
@@ -336,7 +337,7 @@ private:
 
         void OnSize(wxSizeEvent& event);
 
-        void RecreatePluralTextCtrls();
+        void UpdateEditingUIAfterChange();
 
         template<typename TFunctor>
         void ReportValidationErrors(Catalog::ValidationResults validation,
