@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -80,7 +80,7 @@ public:
     bool InitSpellchecker(bool enabled, Language lang);
 
     void SetLanguage(Language lang);
-    void RecreatePluralTextCtrls(CatalogPtr catalog);
+    void UpdateEditingUIForCatalog(CatalogPtr catalog);
 
     void SetSingleSelectionMode();
     void SetMultipleSelectionMode();
@@ -115,6 +115,8 @@ public:
     TranslationTextCtrl *Ctrl_PluralTranslation(size_t index) const { return m_textTransPlural[index]; }
 
 private:
+    void RecreatePluralTextCtrls(CatalogPtr catalog);
+
     void UpdateAuxiliaryInfo(CatalogItemPtr item);
     void UpdateCharCounter(CatalogItemPtr item);
 
@@ -135,6 +137,9 @@ private:
 
     PoeditListCtrl *m_associatedList;
 
+    bool m_isSingleSelection = true;
+    bool m_fuzzyToggleNeeded = true;
+
     bool m_dontAutoclearFuzzyStatus;
 
     SourceTextCtrl *m_textOrig, *m_textOrigPlural;
@@ -148,7 +153,7 @@ private:
     wxStaticText *m_labelSingular, *m_labelPlural;
     wxStaticText *m_labelSource, *m_labelTrans;
 
-    TagLabel *m_tagContext;
+    TagLabel *m_tagIdOrContext;
     TagLabel *m_tagFormat;
     TagLabel *m_tagPretranslated;
 
