@@ -2,7 +2,7 @@
  *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 2003 Christophe Hermier
- *  Copyright (C) 2013-2022 Vaclav Slavik
+ *  Copyright (C) 2013-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -131,9 +131,17 @@ void Catalog::ExportToHTML(std::ostream& f)
             lang_tra += " dir='rtl'";
     }
 
-    auto thead_src = srclang.IsValid()
-                     ? (wxString::Format(_(L"Source text — %s"), srclang.DisplayName()))
-                     : _("Source text");
+    wxString thead_src;
+    if (UsesSymbolicIDsForSource())
+    {
+        thead_src = _("Source text ID");
+    }
+    else
+    {
+        thead_src = srclang.IsValid()
+                    ? (wxString::Format(_(L"Source text — %s"), srclang.DisplayName()))
+                    : _("Source text");
+    }
     auto thead_tra = wxString::Format(_(L"Translation — %s"),
                                       lang.IsValid() ? lang.DisplayName() : _("unknown language"));
 
@@ -164,6 +172,8 @@ void Catalog::ExportToHTML(std::ostream& f)
 
         // Source string:
         f << "<td class='src' " << lang_src << ">\n";
+        if (item->HasSymbolicId())
+            f << " <div class='id'>" << fmt_trans(item->GetSymbolicId()) << "</div>";
         if (item->HasContext())
             f << " <span class='msgctxt'>" << fmt_trans(item->GetContext()) << "</span>";
         if (item->HasPlural())
@@ -341,6 +351,10 @@ tr.comments div {
 tr.comments div p:last-child { margin-bottom: 0; }
 tr.comments td { padding-top: 0; }
 
+.id {
+  font-size: smaller;
+}
+
 .msgctxt {
   font-size: smaller;
   border-radius: 2px;
@@ -357,6 +371,7 @@ body { background-color: #fff; color: #333; }
 .percent-fuzzy   { background-color: rgb(255, 149, 0); height: 10px; }
 .percent-untrans { background-color: #F1F1F1; height: 10px; }
 .legend          { color: #aaa; }
+.id              { color: #aaa; }
 tr.comments div  { color: #aaa; }
 .fuzzy .tra      { color: rgb(230, 134, 0); }
 
@@ -367,6 +382,7 @@ tr.comments div  { color: #aaa; }
     body             { background-color: rgb(45, 42, 41); color: #eee; }
     .percent-untrans { background-color: rgba(255, 255, 255, 0.3); }
     .legend          { color: rgba(255, 255, 255, 0.6); }
+    .id              { color: rgba(255, 255, 255, 0.6); }
     tr.comments div  { color: rgba(255, 255, 255, 0.6); }
     .fuzzy .tra      { color: rgb(253, 178, 72); }
     .msgctxt         { color: rgb(180, 222, 254); background-color: rgba(67, 94, 147, 0.6); }
