@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2021-2022 Vaclav Slavik
+ *  Copyright (C) 2021-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -31,12 +31,14 @@
 
 #include <wx/filename.h>
 
+#include <memory>
+
 
 class FileMonitor
 {
 public:
-    FileMonitor() : m_isRespondingGuard(false) {}
-    ~FileMonitor() { Reset(); }
+    FileMonitor();
+    ~FileMonitor();
 
     void SetFile(wxFileName file);
 
@@ -44,6 +46,8 @@ public:
     {
         if (!m_file.IsOk())
             return false;
+        if (!m_file.FileExists())
+            return false;
         return m_loadTime != m_file.GetModificationTime();
     }
 
@@ -85,6 +89,10 @@ public:
     static void EventLoopStarted();
     static void CleanUp();
 
+    // the following is public only for the needs of filemonitor.cpp implementations:
+    class Impl;
+    static void NotifyFileChanged(const wxString& path);
+
 private:
     void Reset();
 
@@ -93,6 +101,8 @@ private:
     wxString m_monitoredPath;
     wxFileName m_file, m_dir;
     wxDateTime m_loadTime;
+
+    std::unique_ptr<Impl> m_impl;
 };
 
 
