@@ -31,6 +31,7 @@
 #include <mutex>
 #include <memory>
 #include <regex>
+#include <set>
 
 #include <boost/algorithm/string.hpp>
 
@@ -130,10 +131,12 @@ const DisplayNamesData& GetDisplayNamesData()
     std::call_once(of_namesList, [=]{
         auto locEng = icu::Locale::getEnglish();
         std::vector<icu::UnicodeString> names;
+        std::set<std::string> foundCodes;
 
         int32_t count;
         const icu::Locale *loc = icu::Locale::getAvailableLocales(count);
         names.reserve(count);
+
         for (int i = 0; i < count; i++, loc++)
         {
             auto language = loc->getLanguage();
@@ -177,7 +180,9 @@ const DisplayNamesData& GetDisplayNamesData()
                         code += "@cyrillic";
                 }
             }
-            
+
+            foundCodes.insert(code);
+
             s.foldCase();
             data.names[str::to_wstring(s)] = code;
 
@@ -186,6 +191,34 @@ const DisplayNamesData& GetDisplayNamesData()
             data.namesEng[str::to_wstring(s)] = code;
         }
 
+        // add languages that are not listed as locales in ICU:
+        for (const char * const* i = icu::Locale::getISOLanguages(); *i != nullptr; ++i)
+        {
+            const char *code = *i;
+            if (foundCodes.find(code) != foundCodes.end())
+                continue;
+
+            icu::Locale langLoc(code);
+            if (strcmp(code, langLoc.getLanguage()) != 0)
+                continue; // e.g. 'und' for undetermined language
+
+            icu::UnicodeString name;
+            if (langLoc.getDisplayName(name).isEmpty())
+                langLoc.getDisplayLanguage(name);
+            if (name.isEmpty())
+                continue;
+
+            names.push_back(name);
+
+            name.foldCase();
+            data.names[str::to_wstring(name)] = code;
+
+            if (langLoc.getDisplayName(locEng, name).isEmpty())
+                langLoc.getDisplayLanguage(locEng, name);
+            name.foldCase();
+            data.namesEng[str::to_wstring(name)] = code;
+        }
+
         // sort the names alphabetically for data.sortedNames:
         UErrorCode err = U_ZERO_ERROR;
         std::unique_ptr<icu::Collator> coll(icu::Collator::createInstance(err));
@@ -484,7 +517,8 @@ PluralFormsExpr Language::DefaultPluralFormsExpr() const
     if ( i != forms.end() )
         return i->second;
 
-    return PluralFormsExpr();
+    // fall back to English-like singular+plural
+    return PluralFormsExpr::English();
 }
 
 
@@ -505,8 +539,10 @@ icu::Locale Language::ToIcu() const
 
 wxString Language::DisplayName() const
 {
+    auto loc = ToIcu();
     icu::UnicodeString s;
-    ToIcu().getDisplayName(s);
+    if (loc.getDisplayName(s).isEmpty())
+        loc.getDisplayLanguage(s);
     return str::to_wx(s);
 }
 
@@ -521,7 +557,10 @@ wxString Language::DisplayNameInItself() const
 {
     auto loc = ToIcu();
     icu::UnicodeString s;
-    loc.getDisplayName(loc, s);
+    if (loc.getDisplayName(loc, s).isEmpty())
+        loc.getDisplayLanguage(loc, s);
+    if (s.isEmpty())
+        return DisplayName(); // fall back to current locale's name, better than nothing
     return str::to_wx(s);
 }
 
@@ -766,3 +805,8 @@ int PluralFormsExpr::evaluate_for_n(int n) const
     auto c = calc();
     return c ? c->evaluate(n) : 0;
 }
+
+PluralFormsExpr PluralFormsExpr::English()
+{
+    return PluralFormsExpr("nplurals=2; plural=(n != 1);", 2);
+}
