@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2013-2022 Vaclav Slavik
+ *  Copyright (C) 2013-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -127,14 +127,15 @@ LanguageCtrl::LanguageCtrl() : m_inited(false)
 }
 
 LanguageCtrl::LanguageCtrl(wxWindow *parent, wxWindowID winid, Language lang)
-    : wxComboBox(parent, winid)
+    : wxComboBox(parent, winid, "", wxDefaultPosition, wxSize(PX(220), -1))
 {
     Init(lang);
 }
 
 void LanguageCtrl::Init(Language lang)
 {
-    SetHint(_("Language Code or Name (e.g. en_GB)"));
+    // TRANSLATORS: placeholder/hint in language controls
+    SetHint(_("Language name or code"));
 
     // wxGTK must have the value set before autocompletion (but also after it
     // below) to avoid annoying popups in some (hard to determine) cases.
