@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2001-2022 Vaclav Slavik
+ *  Copyright (C) 2001-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -122,10 +122,8 @@ ManagerFrame::ManagerFrame() :
 
     m_listPrj = new wxListBox(panel, wxID_ANY, wxDefaultPosition, wxSize(PX(200), -1), 0, nullptr, MSW_OR_OTHER(wxBORDER_SIMPLE, wxBORDER_SUNKEN));
 #ifdef __WXOSX__
-  #if __MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_16
     if (@available(macOS 11.0, *))
         ((NSTableView*)[((NSScrollView*)m_listPrj->GetHandle()) documentView]).style = NSTableViewStyleFullWidth;
-  #endif
 #endif
     sidebarSizer->Add(m_listPrj, wxSizerFlags(1).Expand());
 
@@ -592,7 +590,7 @@ void ManagerFrame::OnUpdateProject(wxCommandEvent&)
                 {
                     Progress subtask(1, progress, 1);
 
-                    auto cat = std::make_shared<POCatalog>(f);
+                    auto cat = POCatalog::Create(f);
                     UpdateResultReason reason;
                     if (PerformUpdateFromSources(cat, reason))
                     {
