@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -113,7 +113,7 @@ wxMenuBar *MenusManager::CreateMenu(Menu purpose)
     item = bar->FindItem(XRCID("menu_update_from_crowdin"), &menu);
     if (item)
         menu->Destroy(item);
-    item = bar->FindItem(XRCID("menu_open_crowdin"), &menu);
+    item = bar->FindItem(XRCID("menu_open_cloud"), &menu);
     if (item)
         menu->Destroy(item);
 #endif
@@ -152,7 +152,7 @@ void MenusManager::TweakOSXMenuBar(wxMenuBar *bar)
         if (prefsItem)
         {
             // TRANSLATORS: This is Settings app menu that replaces Preferences in macOS 13 Ventura or newer, and should be translated EXACTLY as in macOS. If you don't use macOS and can't check, please leave it untranslated.
-            prefsItem->SetItemLabel(_(L"Settings…"));
+            prefsItem->SetItemLabel(_(L"Settings…") + "\tCtrl+,");
         }
     }
 
