@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2022 Vaclav Slavik
+ *  Copyright (C) 2000-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -59,6 +59,7 @@
 #include "edapp.h"
 #include "edframe.h"
 #include "catalog.h"
+#include "cloud_accounts_ui.h"
 #include "configuration.h"
 #include "crowdin_gui.h"
 #include "hidpi.h"
@@ -90,11 +91,9 @@
 inline wxBitmap MacPageIcon(const char *macos10, const char *macos11)
 {
     (void)macos11;
-#if __MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_16
     if (@available(macOS 11.0, *))
         return wxBitmap([NSImage imageWithSystemSymbolName:str::to_NS(macos11) accessibilityDescription:nil]);
     else
-#endif
         return wxArtProvider::GetBitmap(macos10);
 }
 #else
@@ -548,7 +547,9 @@ private:
             Catalog::GetAllTypesFileMask(),
             wxFD_OPEN | wxFD_FILE_MUST_EXIST | wxFD_MULTIPLE));
 
-        dlg->ShowWindowModalThenDo([=](int retcode){
+        // dlg->ShowWindowModalThenDo([=](int retcode){
+        int retcode = dlg->ShowModal();
+        {
             if (retcode != wxID_OK)
                 return;
 
@@ -564,18 +565,27 @@ private:
             int step = 0;
             for (size_t i = 0; i < paths.size(); i++)
             {
-                auto cat = Catalog::Create(paths[i]);
-                if (!progress.Update(++step))
-                    break;
-                if (cat && cat->IsOk())
+                try
+                {
+                    auto cat = Catalog::Create(paths[i]);
+                    if (!progress.Update(++step))
+                        break;
                     tm->Insert(cat);
-                if (!progress.Update(++step))
-                    break;
+                    if (!progress.Update(++step))
+                        break;
+                }
+                catch (...)
+                {
+                    wxLogError(_(L"Error loading translation file “%s”."), paths[i]);
+                    progress.Update(++step);
+                    if (!progress.Update(++step))
+                        break;
+                }
             }
             progress.Pulse(_(L"Finalizing…"));
             tm->Commit();
             UpdateStats();
-        });
+        }
     }
 
     void OnImportTMX(wxCommandEvent&)
@@ -590,7 +600,9 @@ private:
             wxFD_OPEN | wxFD_FILE_MUST_EXIST | wxFD_MULTIPLE)
         );
 
-        dlg->ShowWindowModalThenDo([=](int retcode){
+        // dlg->ShowWindowModalThenDo([=](int retcode){
+        int retcode = dlg->ShowModal();
+        {
             if (retcode != wxID_OK)
                 return;
 
@@ -634,7 +646,7 @@ private:
                 }
             }
             UpdateStats();
-        });
+        }
     }
 
     void OnExportTMX(wxCommandEvent&)
@@ -649,7 +661,9 @@ private:
             wxFD_SAVE | wxFD_OVERWRITE_PROMPT)
         );
 
-        dlg->ShowWindowModalThenDo([=](int retcode){
+        // dlg->ShowWindowModalThenDo([=](int retcode){
+        int retcode = dlg->ShowModal();
+        {
             if (retcode != wxID_OK)
                 return;
 
@@ -680,7 +694,7 @@ private:
                 err->SetExtendedMessage(DescribeCurrentException());
                 err->ShowWindowModalThenDo([err](int){});
             }
-        });
+        }
     }
 
     void OnResetTM(wxCommandEvent&)
@@ -769,10 +783,8 @@ public:
         m_list->SetMinSize(wxSize(PX(400),PX(200)));
 #ifdef __WXOSX__
         m_list->SetWindowVariant(wxWINDOW_VARIANT_SMALL);
-    #if __MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_16
         if (@available(macOS 11.0, *))
             ((NSTableView*)[((NSScrollView*)m_list->GetHandle()) documentView]).style = NSTableViewStyleFullWidth;
-    #endif
 #endif
         listSizer->Add(m_list, wxSizerFlags(1).Expand().Border(wxLEFT|wxRIGHT, PX(5)));
 
@@ -819,7 +831,7 @@ public:
             //        be rendered correctly, so we just use normal background for now:
             if (ColorScheme::GetWindowMode(this) == ColorScheme::Dark)
             {
-                listPanel->SetBackgroundColour(listPanel->GetDefaultAttributes().colBg);
+                listPanel->SetBackgroundColour(wxNullColour);
             }
             else
 #endif
@@ -1029,17 +1041,18 @@ class AccountsPageWindow : public PrefsPanel
 public:
     AccountsPageWindow(wxWindow *parent) : PrefsPanel(parent)
     {
-        wxSizer *topsizer = new wxBoxSizer(wxVERTICAL);
-        m_login = new CrowdinLoginPanel(this);
-        topsizer->Add(m_login, wxSizerFlags(1).Expand().Border(wxALL, PX(15)));
-        SetSizer(topsizer);
+        wxSizer *sizer = new wxBoxSizer(wxVERTICAL);
+        SetSizer(sizer);
+
+        m_accounts = new AccountsPanel(this);
+        sizer->Add(m_accounts, wxSizerFlags(1).Expand().PXDoubleBorderAll());
 
     #ifdef __WXOSX__
-        // This window was possible created on demand (pre-macOS 11), possibly
+        // This window was possibly created on demand (pre-macOS 11), possibly
         // hidden. Initialize as soon as it is shown:
         Bind(wxEVT_SHOW, [=](wxShowEvent& e){
             if (e.IsShown())
-                CallAfter([=]{ m_login->EnsureInitialized(); });
+                CallAfter([=]{ m_accounts->InitializeAfterShown(); });
         });
     #else
         // On other platforms, notebook pages are all created at once. Don't do
@@ -1052,7 +1065,7 @@ public:
             notebook->Bind(wxEVT_NOTEBOOK_PAGE_CHANGED, [=](wxBookCtrlEvent& e){
                 e.Skip();
                 if (notebook->GetPage(e.GetSelection()) == this)
-                    CallAfter([=]{ m_login->EnsureInitialized(); });
+                    CallAfter([=]{ m_accounts->InitializeAfterShown(); });
             });
         }
     #endif
@@ -1067,7 +1080,7 @@ public:
     }
 
 private:
-    CrowdinLoginPanel *m_login;
+    AccountsPanel *m_accounts;
 };
 
 class AccountsPage : public wxPreferencesPage
@@ -1116,19 +1129,19 @@ public:
         m_updates->SetValue(win_sparkle_get_automatic_check_for_updates() != 0);
 #endif
         m_beta->SetValue(wxGetApp().CheckForBetaUpdates());
-        if (wxGetApp().IsBetaVersion())
-            m_beta->Disable();
     }
 
     void SaveValues(wxConfigBase& cfg) override
     {
+        cfg.Write("check_for_beta_updates", m_beta->GetValue());
 #ifdef __WXMSW__
         win_sparkle_set_automatic_check_for_updates(m_updates->GetValue());
+        // FIXME: don't duplicate this code from PoeditApp::OnInit()
+        if (m_beta->GetValue())
+            win_sparkle_set_appcast_url("https://poedit.net/updates_v2/win/appcast/beta");
+        else
+            win_sparkle_set_appcast_url("https://poedit.net/updates_v2/win/appcast");
 #endif
-        if (!wxGetApp().IsBetaVersion())
-        {
-            cfg.Write("check_for_beta_updates", m_beta->GetValue());
-        }
 #ifdef USE_SPARKLE
         UserDefaults_SetBoolValue("SUEnableAutomaticChecks", m_updates->GetValue());
 #endif
