@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2020-2022 Vaclav Slavik
+ *  Copyright (C) 2020-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -26,7 +26,8 @@
 #ifndef Poedit_recent_files_h
 #define Poedit_recent_files_h
 
-#include <wx/dataview.h>
+#include "customcontrols.h"
+
 #include <wx/event.h>
 
 #include <memory>
@@ -77,7 +78,7 @@ private:
 
 
 /// Control with a list of recently opened files
-class RecentFilesCtrl : public wxDataViewListCtrl
+class RecentFilesCtrl : public IconAndSubtitleListCtrl
 {
 public:
     RecentFilesCtrl(wxWindow *parent);
@@ -86,8 +87,6 @@ private:
     void RefreshContent();
     void OnActivate(wxDataViewEvent& event);
 
-    class MultilineTextRenderer;
-
     struct data;
     std::unique_ptr<data> m_data;
 };
