@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2022 Vaclav Slavik
+ *  Copyright (C) 2014-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -374,7 +374,7 @@ public:
         if (m_isPerfect)
             m_isPerfect->GetContainingSizer()->Show(m_isPerfect, percent == 100);
 
-        auto text = wxControl::EscapeMnemonics(bidi::mark_direction(s.text, lang));
+        auto text = bidi::mark_direction(s.text, lang);
 
         m_text->SetLanguage(lang);
         m_text->SetAndWrapLabel(text);
@@ -426,18 +426,10 @@ private:
         {
 #ifdef __WXOSX__
             auto winbg = GetBackgroundColour();
-            wxColour highlight;
-            if (@available(macOS 10.14, *))
-            {
-                NSColor *bg = winbg.OSXGetNSColor();
-                NSColor *osHighlight = [bg colorWithSystemEffect:NSColorSystemEffectRollover];
-                // use only lighter version of the highlight by blending with the background
-                highlight = wxColour([bg blendedColorWithFraction:0.2 ofColor:osHighlight]);
-            }
-            else
-            {
-                highlight = winbg.ChangeLightness(95);
-            }
+            NSColor *bg = winbg.OSXGetNSColor();
+            NSColor *osHighlight = [bg colorWithSystemEffect:NSColorSystemEffectRollover];
+            // use only lighter version of the highlight by blending with the background
+            auto highlight = wxColour([bg blendedColorWithFraction:0.2 ofColor:osHighlight]);
 #else
             auto highlight = m_bgHighlight;
 #endif
@@ -638,6 +630,7 @@ void SuggestionsSidebarBlock::ClearMessage()
     m_msgText->SetAndWrapLabel("");
     UpdateVisibility();
     m_suggestionsPanel->Layout();
+    m_panelSizer->Layout();
 }
 
 void SuggestionsSidebarBlock::SetMessage(const wxString& icon, const wxString& text)
@@ -647,6 +640,7 @@ void SuggestionsSidebarBlock::SetMessage(const wxString& icon, const wxString& t
     m_msgText->SetAndWrapLabel(text);
     UpdateVisibility();
     m_suggestionsPanel->Layout();
+    m_panelSizer->Layout();
 }
 
 void SuggestionsSidebarBlock::ReportError(SuggestionsBackend*, dispatch::exception_ptr e)
@@ -873,6 +867,18 @@ void SuggestionsSidebarBlock::UpdateSuggestionsForItem(CatalogItemPtr item)
 
     m_pendingQueries = 0;
 
+    // FIXME: Get catalog info from `item` once present there
+    if (m_parent->GetCatalog()->UsesSymbolicIDsForSource())
+    {
+        SetMessage("SuggestionErrorTemplate", _(L"Translation suggestions require that source text is available. They don’t work if only IDs without the actual text are used."));
+        return;
+    }
+    else if (!m_parent->GetCatalog()->GetSourceLanguage().IsValid())
+    {
+        SetMessage("SuggestionErrorTemplate", _(L"Translation suggestions require that source text’s language is known. Poedit couldn’t detect it in this file."));
+        return;
+    }
+
     auto srclang = m_parent->GetCurrentSourceLanguage();
     auto lang = m_parent->GetCurrentLanguage();
     if (!srclang.IsValid() || !lang.IsValid() || srclang == lang)
@@ -892,6 +898,12 @@ void SuggestionsSidebarBlock::OnDelayedShowSuggestionsForItem(wxTimerEvent&)
 void SuggestionsSidebarBlock::QueryAllProviders(const CatalogItemPtr& item)
 {
     auto thisQueryId = ++m_latestQueryId;
+
+    // At this point, we know we're not interested in any older results, but some might have
+    // arrived asynchronously in between ClearSuggestions() call and now. So make sure there
+    // are no old suggestions present right after increasing the query ID:
+    m_suggestions.clear();
+
     QueryProvider(TranslationMemory::Get(), item, thisQueryId);
 }
 
