@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2022 Vaclav Slavik
+ *  Copyright (C) 2014-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -206,6 +206,8 @@ std::wregex REOBJ_COMMON_PLACEHOLDERS(
                 //
                 RegexSyntaxHighlighter::flags);
 
+// WebExtension-like $foo$ placeholders
+std::wregex REOBJ_DOLLAR_PLACEHOLDERS(LR"(\$[A-Za-z0-9_]+\$)", RegexSyntaxHighlighter::flags);
 
 // php-format per http://php.net/manual/en/function.sprintf.php plus positionals
 const wchar_t* RE_PHP_FORMAT = LR"(%(\d+\$)?[-+]{0,2}([ 0]|'.)?-?\d*(\..?\d+)?[%bcdeEfFgGosuxX])";
@@ -215,6 +217,7 @@ const wchar_t* RE_PHP_FORMAT = LR"(%(\d+\$)?[-+]{0,2}([ 0]|'.)?-?\d*(\..?\d+)?[%
 #define RE_C_FORMAT_BASE LR"(%(\d+\$)?[-+ #0]{0,5}(\d+|\*)?(\.(\d+|\*))?(hh|ll|[hljztL])?[%csdioxXufFeEaAgGnp])"
 const wchar_t* RE_C_FORMAT = RE_C_FORMAT_BASE;
 const wchar_t* RE_OBJC_FORMAT =  L"%@|" RE_C_FORMAT_BASE;
+const wchar_t* RE_CXX20_FORMAT = LR"((\{\{)|(\}\})|(\{[^}]*\}))";
 
 // Python and Perl-libintl braces format (also covered by common placeholders above)
 #define RE_BRACES LR"(\{[\w.-:,]+\})"
@@ -241,9 +244,12 @@ const wchar_t* RE_PASCAL_FORMAT = LR"(%(\*:|\d*:)?-?(\*|\d+)?(\.\*|\.\d+)?[dDuUx
 } // anonymous namespace
 
 
-SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kindsMask)
+SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kindsMask, int flags)
 {
     auto fmt = item.GetFormatFlag();
+    if (fmt.empty())
+        fmt = item.GetInternalFormatFlag();
+
     bool needsHTML = (kindsMask & Markup);
     if (needsHTML)
     {
@@ -253,7 +259,7 @@ SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kin
     bool needsGenericPlaceholders = (kindsMask & Placeholder);
     if (needsGenericPlaceholders)
     {
-        if ((kindsMask & EnforceFormatTag) && !fmt.empty())
+        if ((flags & EnforceFormatTag) && !fmt.empty())
         {
             // only use generic placeholders if no explicit format was provided, see https://github.com/vslavik/poedit/issues/777
             needsGenericPlaceholders = false;
@@ -302,6 +308,11 @@ SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kin
             static auto c_format = std::make_shared<RegexSyntaxHighlighter>(RE_C_FORMAT, TextKind::Placeholder);
             all->Add(c_format);
         }
+        else if (fmt == "c++")
+        {
+            static auto cxx_format = std::make_shared<RegexSyntaxHighlighter>(RE_CXX20_FORMAT, TextKind::Placeholder);
+            all->Add(cxx_format);
+        }
         else if (fmt == "python")
         {
             static auto python_format = std::make_shared<RegexSyntaxHighlighter>(RE_PYTHON_FORMAT, TextKind::Placeholder);
@@ -337,6 +348,11 @@ SyntaxHighlighterPtr SyntaxHighlighter::ForItem(const CatalogItem& item, int kin
             static auto pascal_format = std::make_shared<RegexSyntaxHighlighter>(RE_PASCAL_FORMAT, TextKind::Placeholder);
             all->Add(pascal_format);
         }
+        else if (fmt == "ph-dollars")
+        {
+            static auto dollars_format = std::make_shared<RegexSyntaxHighlighter>(REOBJ_DOLLAR_PLACEHOLDERS, TextKind::Placeholder);
+            all->Add(dollars_format);
+        }
     }
 
     // basic highlighting has highest priority, so should come last in the order:
