@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2013-2022 Vaclav Slavik
+ *  Copyright (C) 2013-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -28,7 +28,6 @@
 #include "colorscheme.h"
 #include "custom_buttons.h"
 #include "customcontrols.h"
-#include "crowdin_gui.h"
 #include "edapp.h"
 #include "edframe.h"
 #include "hidpi.h"
@@ -41,6 +40,7 @@
 #include <wx/dcbuffer.h>
 #include <wx/statbmp.h>
 #include <wx/stattext.h>
+#include <wx/stdpaths.h>
 #include <wx/sizer.h>
 #include <wx/artprov.h>
 #include <wx/font.h>
@@ -90,8 +90,7 @@ public:
         auto label = new SecondaryLabel(this, title);
         auto sizer = new wxBoxSizer(wxVERTICAL);
         sizer->AddStretchSpacer();
-        sizer->Add(label, wxSizerFlags().Left().Border(wxLEFT, PX(10)));
-        //sizer->AddSpacer(PX(4));
+        sizer->Add(label, wxSizerFlags().Left().Border(wxLEFT, PX(8)));
         sizer->AddStretchSpacer();
         SetSizer(sizer);
     }
@@ -248,7 +247,7 @@ WelcomeWindow::WelcomeWindow()
 #ifdef __WXMSW__
     if (GetMenuWindow())
     {
-        leftoutersizer->Add(GetMenuWindow(), wxSizerFlags().Left());
+        leftoutersizer->Add(GetMenuWindow(), wxSizerFlags().Left().Border(wxALL, PX(4)));
     }
 #endif
 
@@ -286,7 +285,7 @@ WelcomeWindow::WelcomeWindow()
 
     leftsizer->Add(new ActionButton(
                        this, XRCID("menu_new_from_pot"), "CreateTranslation",
-                       _(L"Create new…"),
+                       _("Create new"),
                        _("Create new translation from POT template.")),
                wxSizerFlags().Border(wxTOP, PX(2)).Expand());
 
@@ -298,10 +297,12 @@ WelcomeWindow::WelcomeWindow()
 
 #ifdef HAVE_HTTP_CLIENT
     leftsizer->Add(new ActionButton(
-                       this, XRCID("menu_open_crowdin"), "Collaborate",
-                       _("Translate Crowdin project"),
-                       _("Collaborate with others in a Crowdin project.")),
-               wxSizerFlags().Border(wxTOP|wxBOTTOM, PX(2)).Expand());
+                       this, XRCID("menu_open_cloud"), "Collaborate",
+                       _("Translate cloud project"),
+                       _("Collaborate with other people online.")),
+               wxSizerFlags().Border(wxTOP, PX(2)).Expand());
+    auto learnCloud = new LearnMoreLink(this, "https://poedit.net/cloud-sync", _("How does cloud sync work?"));
+    leftsizer->Add(learnCloud, wxSizerFlags().Left().Border(wxLEFT, MACOS_OR_OTHER(PX(18), PX(8))));
 #endif // HAVE_HTTP_CLIENT
 
     leftoutersizer->Add(leftsizer, wxSizerFlags().Center().Border(wxALL, PX(50)));
